@@ -1,6 +1,6 @@
 #  -*- coding: utf-8 -*-
 
-# Copyright 2020 FanFicFare team
+# Copyright 2021 FanFicFare team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -229,7 +229,14 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
         ## img class="lazyload"
         ## include lazy load images.
         for img in soup.find_all('img',{'class':'lazyload'}):
-            img['src'] = img['data-src']
+            # logger.debug("img:%s"%img)
+            ## SV at least has started using data-url instead of
+            ## data-src, notably for <img> inside <noscript>?
+            if img.has_attr('data-src'):
+                img['src'] = img['data-src']
+            if img.has_attr('data-url'):
+                img['src'] = img['data-url']
+            # logger.debug("\n\nimg:%s\n"%img)
 
         ## after lazy load images, there are noscript blocks also
         ## containing <img> tags.  The problem comes in when they hit
@@ -296,9 +303,16 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
             threadmarkgroups[tmcat_name]=self.fetch_threadmarks(href,
                                                                 tmcat_name,
                                                                 tmcat_num)
+
+        # sort groups named in list
+        # order_threadmarks_by_date_categories by date at beginning
+        # of list, then rest grouped normally.
+        date_sort_threadmarks = []
+        grouped_threadmarks = []
+        date_sort_groups = self.getConfigList('order_threadmarks_by_date_categories',[])
         ## Order of threadmark groups in new SV is changed and
-        ## possibly unpredictable.  Normalize.  Keep as configurable?
-        ## What about categories not in the list?
+        ## possibly unpredictable.  Normalize, but configurable.
+        ## Categories not in the list go at the end alphabetically.
         default_order = ['Threadmarks',
                          'Sidestory',
                          'Apocrypha',
@@ -312,7 +326,10 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
         # order.
         for cat_name in self.getConfigList('threadmark_category_order',default_order)+default_order:
             if cat_name in threadmarkgroups:
-                threadmarks.extend(threadmarkgroups[cat_name])
+                if cat_name in date_sort_groups:
+                    date_sort_threadmarks.extend(threadmarkgroups[cat_name])
+                else:
+                    grouped_threadmarks.extend(threadmarkgroups[cat_name])
                 del threadmarkgroups[cat_name]
         # more categories left?  new or at least unknown
         if threadmarkgroups:
@@ -320,7 +337,17 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
             # alphabetize for lack of a better idea to insure consist ordering
             cats.sort()
             for cat_name in cats:
-                threadmarks.extend(threadmarkgroups[cat_name])
+                if cat_name in date_sort_groups:
+                    date_sort_threadmarks.extend(threadmarkgroups[cat_name])
+                else:
+                    grouped_threadmarks.extend(threadmarkgroups[cat_name])
+        if date_sort_threadmarks:
+            date_sort_threadmarks = sorted(date_sort_threadmarks, key=lambda x: x['date'])
+
+        threadmarks = date_sort_threadmarks + grouped_threadmarks
+        ## older setting, threadmarks_categories_ordered_by_date supercedes.
+        if self.getConfig('order_threadmarks_by_date') and not self.getConfig('order_threadmarks_by_date_categories'):
+            threadmarks = sorted(threadmarks, key=lambda x: x['date'])
         return threadmarks
 
     def get_threadmarks_list(self,soupmarks):
@@ -464,8 +491,8 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
             souptag = self.get_cache_post(anchorid)
 
         else:
-            ## Also sets datePublished / dateUpdated to oldest / newest post datetimes.
             threadmarks = self.extract_threadmarks(souptag)
+            souptag = self.get_first_post(topsoup)
 
             if len(threadmarks) >= int(self.getConfig('minimum_threadmarks',2)):
                 # remember if reader link found--only applicable if using threadmarks.
@@ -476,10 +503,21 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
 
                 use_threadmark_chaps = True
 
-                # spin threadmarks for date, to adjust tmcat_name/prepend.
+                # Set initial created/updated dates from the 'first'
+                # posting created.  Updated below for newer updated
+                # (or older published)
+                date = self.get_post_created_date(souptag)
+                if date:
+                    self.story.setMetadata('datePublished', date)
+                    self.story.setMetadata('dateUpdated', date)
+                # logger.debug("#"*100)
+                # # logger.debug(souptag)
+                # logger.debug(self.story.getMetadata('datePublished'))
+                # logger.debug("#"*100)
+
+                # spin threadmarks for words and to adjust tmcat_name/prepend.
+                # (apocrypha->omake should have already be done in extract_threads()?)
                 words = 0
-                if self.getConfig('order_threadmarks_by_date'):
-                    threadmarks = sorted(threadmarks, key=lambda x: x['date'])
                 for tm in threadmarks:
                     # {"tmcat_name":tmcat_name,"tmcat_num":tmcat_num,"tmcat_index":tmcat_index,"title":title,"url":url,"date":date}
                     prepend=""
@@ -511,7 +549,6 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
 
                 if words and self.getConfig('use_threadmark_wordcounts',True):
                     self.story.setMetadata('numWords',words)
-            souptag = self.get_first_post(topsoup)
 
         if use_threadmark_chaps:
             self.set_threadmarks_metadata(useurl,topsoup)
@@ -750,6 +787,10 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
                 div.button.extract()
 
     def _do_utf8FromSoup(self,url,soup,fetch=None,allow_replace_br_with_p=True):
+        if self.getConfig('reveal_invisible_text'):
+            ## when set, remove style='color:transparent'.
+            for span in soup.find_all('span',style='color:transparent'):
+                del span['style']
         if self.getConfig('replace_failed_smilies_with_alt_text'):
             for img in soup.find_all('img',src=re.compile(r'(^data:image|(failedtoload|clear.png)$)')):
                 # logger.debug("replace_failed_smilies_with_alt_text img: %s"%img)
